@@ -3,11 +3,12 @@
 from unittest import mock
 
 from eldonationtracker.api import team as team
+import donordrivepython.api.comms
 
 
 def test_team_urls():
     """Test that URL construction is correct."""
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     assert my_team.team_url == "https://www.extra-life.org/api/teams/12345"
     assert my_team.team_participant_url == "https://www.extra-life.org/api/teams/12345/participants"
     assert my_team.team_donation_url == "https://www.extra-life.org/api/teams/12345/donations"
@@ -15,31 +16,31 @@ def test_team_urls():
 
 def test_output_folder():
     """Test that the program correctly parses the output folder."""
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     assert my_team.output_folder == "folder"
 
 
 def test_donors_to_display():
     """Test that the program correct parses the number of donors to display."""
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     assert my_team.donors_to_display == "5"
 
 
 def test_get_team_json():
     """Test that the JSON we get back is correctly interpreted."""
-    with mock.patch("eldonationtracker.api.team.extralife_io.get_json",
+    with mock.patch("donordrivepython.api.team.donor_drive_comms.get_json",
                     return_value={"fundraisingGoal": 500, "captainDisplayName": "Captain Awesome",
                                   "sumDonations": 400, "numDonations": 300,
                                   "avatarImageURL": "//assets.donordrive.com/…avatar-team-default.gif"}):
-        my_team = team.Team("12345", "folder", "$", "5")
+        my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
         team_json = my_team._get_team_json()
         assert team_json == (500, 'Captain Awesome', 400, 300, "//assets.donordrive.com/…avatar-team-default.gif")
 
 
 def test_get_team_json_no_json():
     """Test to make sure if no JSON is returned from the endpoint, the program responds correcty."""
-    with mock.patch("eldonationtracker.api.team.extralife_io.get_json", return_value={}):
-        my_team = team.Team("12345", "folder", "$", "5")
+    with mock.patch("donordrivepython.api.comms.get_json", return_value={}):
+        my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
         team_json = my_team._get_team_json()
         assert team_json == (0, '', 0, 0, '')
         # let's pretend that at some point values were added
@@ -54,7 +55,7 @@ def test_get_team_json_no_json():
 
 
 def test_update_team_dictionary():
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     my_team._team_goal = 500
     my_team._team_captain = 'Captain Awesome'
     my_team._total_raised = 400
@@ -64,7 +65,7 @@ def test_update_team_dictionary():
 
 
 def test_get_participants_no_participants():
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     with mock.patch("eldonationtracker.api.team.extralife_io.get_json", return_value={}):
         participants = my_team._get_participants(False)
         assert participants == []
@@ -72,7 +73,7 @@ def test_get_participants_no_participants():
 
 
 def test_get_participants():
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     team_participants = [{"displayName":"Karl Abraham",
                           "fundraisingGoal":500.00,
                           "eventName":"Extra Life 2020",
@@ -98,14 +99,14 @@ def test_get_participants():
                           "participantID":410654,"teamName":"Giant Bomb",
                           "avatarImageURL":"//assets.donordrive.com/extralife/images/$avatars$/constituent_0AFEA929-C29F-F29A-6B659B3718802B75.jpg",
                           "teamID":50394,"isTeamCaptain":False,"sumPledges":0.00,"numDonations":1}]
-    with mock.patch("eldonationtracker.api.team.extralife_io.get_json", return_value=team_participants):
+    with mock.patch("donordrivepython.api.team.donor_drive_comms.get_json", return_value=team_participants):
         participants = my_team._get_participants(False)
         assert participants[0].name == "Karl Abraham"
         assert participants[1].name == "Ben Tolmachoff"
 
 
 def test_get_participants_no_participants_top_5():
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     with mock.patch("eldonationtracker.api.team.extralife_io.get_json", return_value={}):
         participants = my_team._get_participants(True)
         assert participants == []
@@ -119,7 +120,7 @@ def test_get_participants_top_5():
     of what the code has to do with what it gets back, there is no difference. So I have just copied things
     to ensure I'm considering both parts of the if statement in this function.
     """
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     team_participants = [{"displayName":"Karl Abraham",
                           "fundraisingGoal":500.00,
                           "eventName":"Extra Life 2020",
@@ -145,20 +146,20 @@ def test_get_participants_top_5():
                           "participantID":410654,"teamName":"Giant Bomb",
                           "avatarImageURL":"//assets.donordrive.com/extralife/images/$avatars$/constituent_0AFEA929-C29F-F29A-6B659B3718802B75.jpg",
                           "teamID":50394,"isTeamCaptain":False,"sumPledges":0.00,"numDonations":1}]
-    with mock.patch("eldonationtracker.api.team.extralife_io.get_json", return_value=team_participants):
+    with mock.patch("donordrivepython.api.team.donor_drive_comms.get_json", return_value=team_participants):
         participants = my_team._get_participants(True)
         assert participants[0].name == "Karl Abraham"
         assert participants[1].name == "Ben Tolmachoff"
 
 
 def test_top_participant_no_participants():
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     top_participant = my_team._top_participant()
     assert top_participant == "No participants."
 
 
 def test_top_participant():
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     team_participants = [{"displayName":"Karl Abraham",
                           "fundraisingGoal":500.00,
                           "eventName":"Extra Life 2020",
@@ -184,7 +185,7 @@ def test_top_participant():
                           "participantID":410654,"teamName":"Giant Bomb",
                           "avatarImageURL":"//assets.donordrive.com/extralife/images/$avatars$/constituent_0AFEA929-C29F-F29A-6B659B3718802B75.jpg",
                           "teamID":50394,"isTeamCaptain":False,"sumPledges":0.00,"numDonations":1}]
-    with mock.patch("eldonationtracker.api.team.extralife_io.get_json", return_value=team_participants):
+    with mock.patch("donordrivepython.api.team.donor_drive_comms.get_json", return_value=team_participants):
         my_team._top_5_participant_list = my_team._get_participants(True)
         top_participant = my_team._top_participant()
         assert top_participant == "Karl Abraham - $0.00"
@@ -192,7 +193,7 @@ def test_top_participant():
 
 def test_participant_calculations_no_data():
     """What if the API comes back empty? Maybe a team just formed without any members?"""
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     my_team._participant_calculations()
     assert my_team._participant_calculation_dict['Team_TopParticipantNameAmnt'] == "No participants."
     assert my_team._participant_calculation_dict['Team_Top5ParticipantsHorizontal'] == ""
@@ -200,7 +201,7 @@ def test_participant_calculations_no_data():
 
 
 def test_participant_calculations():
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     team_participants = [{"displayName":"Karl Abraham",
                           "fundraisingGoal":500.00,
                           "eventName":"Extra Life 2020",
@@ -226,7 +227,7 @@ def test_participant_calculations():
                           "participantID":410654,"teamName":"Giant Bomb",
                           "avatarImageURL":"//assets.donordrive.com/extralife/images/$avatars$/constituent_0AFEA929-C29F-F29A-6B659B3718802B75.jpg",
                           "teamID":50394,"isTeamCaptain":False,"sumPledges":0.00,"numDonations":1}]
-    with mock.patch("eldonationtracker.api.team.extralife_io.get_json", return_value=team_participants):
+    with mock.patch("donordrivepython.api.team.donor_drive_comms.get_json", return_value=team_participants):
         my_team._top_5_participant_list = my_team._get_participants(True)
         my_team._participant_calculations()
         assert my_team._participant_calculation_dict['Team_TopParticipantNameAmnt'] == "Karl Abraham - $0.00"
@@ -246,8 +247,9 @@ fake_badge_run = mock.Mock()
 @mock.patch.object(team.Team, "participant_run", fake_participant_run)
 @mock.patch.object(team.Team, "write_text_files", fake_write_text_files)
 @mock.patch.object(team.Team, "donation_run", fake_donation_run)
+@mock.patch.object(team.Team, "_update_badges", fake_badge_run)
 def test_team_run():
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     my_team.team_run()
     assert fake_participant_run.call_count == 1
     my_team.team_run()
@@ -269,7 +271,7 @@ fake_output_badge_data = mock.Mock()
 @mock.patch.object(team.Team, "_update_badges", fake_badge_run)
 @mock.patch.object(team.extralife_io, "output_badge_data", fake_output_badge_data)
 def test_team_api_info():
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     my_team.team_api_info()
     assert my_team.team_goal == 400
     assert my_team.team_captain == "Captain"
@@ -283,13 +285,13 @@ def test_team_api_info():
 
 def test_str_no_json_data():
     """Test what str will produce if the JSON retrieval hasn't yet run."""
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     assert str(my_team) == "A team found at https://www.extra-life.org/api/teams/12345. "
 
 
 def test_str():
     """Test what str will produce after team_info has been filled out."""
-    my_team = team.Team("12345", "folder", "$", "5")
+    my_team = team.Team("12345", "folder", "$", "5", "https://www.extra-life.org/api")
     my_team._team_info["Team_goal"] = '$400.00'
     assert str(my_team) == "A team found at https://www.extra-life.org/api/teams/12345. Team goal is $400.00."
 
@@ -299,5 +301,5 @@ def test_str_no_json_data_no_team_id():
 
     This would happen if the user is not part of a team.
     """
-    my_team = team.Team(None, "folder", "$", "5")
+    my_team = team.Team(None, "folder", "$", "5", "https://www.extra-life.org/api")
     assert str(my_team) == "Not a valid team - no team_id."
